# Generated by Django 2.0.8 on 2019-02-15 11:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("uk_geo_utils", "0006_auto_20180612_1655")]

    operations = [migrations.RemoveField(model_name="onsud", name="ctry_flag")]
