# -*- coding: utf-8 -*-
# Generated by Django 1.11.10 on 2018-03-05 16:33
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("uk_geo_utils", "0004_auto_20180228_1553")]

    operations = [
        migrations.AddField(
            model_name="onsud",
            name="ced",
            field=models.CharField(blank=True, max_length=9),
        )
    ]
